#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `prettyqt` package."""

import pytest

from prettyqt import widgets, gui, core

app = widgets.Application.create_default_app()
test_widget = widgets.Widget()


def test_buttondelegate():
    delegate = widgets.ButtonDelegate(parent=None)


def test_callout():
    callout = widgets.Callout()
    # callout.boundingRect()
    callout.set_text("test")


def test_imageviewer():
    widget = widgets.ImageViewer()


def test_markdownwidget():
    widget = widgets.MarkdownWindow()


def test_popupinfo():
    popup = widgets.PopupInfo()
    popup.show_popup("test")


def test_selectionwidget():
    widget = widgets.SelectionWidget()
    items = {"Semicolon": ";",
             "Tab": "\t",
             "Comma": ","}
    widget.add_items(items)
    widget.add_custom(regex=r"\S{1}")
    choice = widget.current_choice()
    assert(choice == ";")


def test_spanslider():
    slider = widgets.SpanSlider()
    slider.set_lower_value(10)
    slider.set_upper_value(20)
    slider.set_lower_pos(15)
    slider.set_upper_pos(25)
    assert(slider.lower_value == 15)
    assert(slider.upper_value == 25)
    color = gui.Color("blue").lighter(150)
    slider.set_left_color(color)
    slider.set_right_color(color)
    slider.swap_controls()
    slider.trigger_action(slider.SliderNoAction, True)
    slider.trigger_action(slider.SliderSingleStepAdd, True)
    slider.paintEvent(None)
    slider.pixel_pos_to_value(100)
    slider.draw_span(gui.Painter(), core.Rect())
    slider.move_pressed_handle()
    assert(slider.movement_mode is None)


def test_waitingspinner():
    spinner = widgets.WaitingSpinner(parent=test_widget)
    spinner.paintEvent(None)
    spinner.start()
    spinner.stop()
    spinner.update_position()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from typing import Dict

import qtawesome as qta
from qtpy import QtCore, QtWidgets

from prettyqt import widgets

DOCK_POSITIONS = dict(top=QtCore.Qt.TopDockWidgetArea,
                      bottom=QtCore.Qt.BottomDockWidgetArea,
                      left=QtCore.Qt.LeftDockWidgetArea,
                      right=QtCore.Qt.RightDockWidgetArea)


class MainWindow(QtWidgets.QMainWindow):
    """
    Class for our mainWindow
    includes all docks, a centralwidget and a toolbar
    """

    # def load_window_state(self):
    #     prefix = os.environ["QT_API"]
    #     geom = application.settings.get(f"{prefix}.geometry", self.saveGeometry())
    #     state = application.settings.get(f"{prefix}.state", self.saveState())
    #     self.restoreGeometry(geom)
    #     self.restoreState(state)

    # def closeEvent(self, event):
    #     """
    #     override, gets executed when app gets closed.
    #     saves GUI settings
    #     """
    #     prefix = os.environ["QT_API"]
    #     application.settings[f"{prefix}.geometry"] = self.saveGeometry()
    #     application.settings[f"{prefix}.state"] = self.saveState()
    #     super().closeEvent(event)
    #     event.accept()

    def set_icon(self, icon):
        if icon:
            if isinstance(icon, str):
                icon = qta.icon(icon, color="lightgray")
            self.setWindowIcon(icon)

    def set_stylesheet(self, item, dct: Dict[str, str]) -> str:
        ss = "; ".join(f"{k.replace('_', '-')}: {v}" for k, v in dct.items())
        self.setStyleSheet(f"{item} {{{ss};}}")

    def add_dockwidget(self,
                       name: str,
                       title: str,
                       vertical: bool = True,
                       position: str = "left") -> widgets.DockWidget:
        dock_widget = widgets.DockWidget(self, name=name, title=title)
        widget = widgets.Widget()
        widget.setObjectName(f"{name}.widget")
        if vertical:
            layout = QtWidgets.QVBoxLayout(widget)
        else:
            layout = QtWidgets.QHBoxLayout(widget)
        layout.setContentsMargins(0, 0, 0, 0)
        dock_widget.setWidget(widget)
        position = DOCK_POSITIONS[position]
        self.addDockWidget(QtCore.Qt.DockWidgetArea(position), dock_widget)
        dock_widget.layout = layout
        return dock_widget

    def toggle_fullscreen(self):
        """toggle between fullscreen and regular size
        """
        if self.isFullScreen():
            self.showNormal()
        else:
            self.showFullScreen()


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    form = MainWindow()
    form.show()
    app.exec_()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `prettyqt` package."""

import pytest

from qtpy import QtGui
from prettyqt import widgets, core

app = widgets.Application.create_default_app()


@pytest.fixture
def response():
    """Sample pytest fixture.

    See more at: http://doc.pytest.org/en/latest/fixture.html
    """
    return widgets.Callout()


def test_action():
    action = widgets.Action()
    action.set_tooltip("test")
    return True


def test_application():
    app.set_icon("mdi.timer")
    app.set_metadata(app_name="test",
                     app_version="1.0.0",
                     org_name="test",
                     org_domain="test")
    app.get_mainwindow()
    return True


def test_boxlayout():
    layout = widgets.BoxLayout("horizontal")
    widget = widgets.Widget()
    layout.addWidget(widget)
    layout.set_size_mode("maximum")
    assert(len(layout) == 1)
    return True


def test_buttongroup():
    group = widgets.ButtonGroup()
    return True


def test_checkbox():
    chk = widgets.CheckBox()
    chk.show()
    chk.close()


def test_colordialog():
    dlg = widgets.ColorDialog()
    dlg.show()
    dlg.close()


def test_combobox():
    box = widgets.ComboBox()
    box.show()
    box.close()


def test_desktopwidget():
    box = widgets.DesktopWidget()
    return True


def test_dialog():
    dlg = widgets.Dialog(layout="horizontal")
    dlg.set_modality()
    dlg.delete_on_close()
    dlg.add_widget(widgets.Widget())
    dlg.set_icon("mdi.timer")
    dlg.add_buttonbox()
    dlg.show()
    dlg.close()


def test_dialogbuttonbox():
    box = widgets.DialogButtonBox()
    box.set_horizontal()
    box.set_vertical()
    box.add_buttons(["apply"])
    box.show()
    box.close()


def test_dockwidget():
    widget = widgets.DockWidget()
    widget.setup_title_bar()
    widget.maximise()
    widget.show()
    widget.close()


def test_doublespinbox():
    widget = widgets.DoubleSpinBox()
    widget.show()
    widget.close()


def test_filedialog():
    dlg = widgets.FileDialog()
    dlg.set_label_text("accept", "test")
    dlg.set_accept_mode("open")
    dlg.set_accept_mode("save")
    dlg.set_filter(dict(a=[".csv"]))
    dlg.show()
    dlg.close()


def test_fontdialog():
    dlg = widgets.FontDialog()
    dlg.show()
    dlg.close()


def test_formlayout():
    widget = widgets.FormLayout()
    widget.set_size_mode("maximum")
    widget.set_label_widget(0, "test")
    widget.set_label_widget(0, widgets.Widget())
    widget.set_field_widget(0, "test")
    widget.set_field_widget(0, widgets.Widget())
    widget.set_spanning_widget(0, "test")
    widget.set_spanning_widget(0, widgets.Widget())
    widget = widgets.FormLayout.from_dict({"2": "4"})
    assert(len(widget) == 2)
    return True


def test_frame():
    widget = widgets.Frame()
    widget.show()
    widget.close()


def test_gridlayout():
    layout = widgets.GridLayout()
    widget = widgets.Widget()
    layout[0:1, 0:3] = widget
    layout.set_size_mode("maximum")
    layout.set_alignment("left")
    assert len(layout) == len(list(layout)) == 1


def test_groupbox():
    widget = widgets.GroupBox()
    widget.show()
    widget.close()


def test_headerview():
    widget = widgets.HeaderView(parent=None)
    widget.show()
    widget.close()


def test_label():
    label = widgets.Label()
    label.set_image("")
    label.set_alignment(horizontal="left", vertical="top")
    label.show()
    label.close()


def test_lineedit():
    widget = widgets.LineEdit("Test")
    widget.set_regex_validator("[0-9]")
    widget.set_font("Consolas")
    widget.setText("0")
    widget.append("a")
    widget.show()
    widget.close()


def test_listview():
    widget = widgets.ListView()
    widget.show()
    widget.close()


def test_mainwindow():
    window = widgets.MainWindow()
    window.set_icon("mdi.timer")
    window.add_dockwidget("test", "Test")
    window.toggle_fullscreen()
    window.show()
    window.close()


def test_menu():
    menu = widgets.Menu("1")
    action = widgets.Action("test")
    menu.addAction(action)
    menu.show()


def test_menubar():
    menu = widgets.MenuBar()
    menu.show()


def test_messagebox():
    widget = widgets.MessageBox()
    widget.show()


def test_plaintextedit():
    widget = widgets.PlainTextEdit()
    widget.set_text("hallo")
    widget.show()


def test_progressbar():
    widget = widgets.ProgressBar()
    widget.show()


def test_progressdialog():
    widget = widgets.ProgressDialog()
    widget.show()


def test_pushbutton():
    widget = widgets.PushButton("Test")
    widget.show()


def test_radiobutton():
    widget = widgets.RadioButton("Test")
    widget.show()


def test_slider():
    widget = widgets.Slider()
    widget.show()


def test_spinbox():
    widget = widgets.SpinBox()
    widget.show()


def test_splitter():
    widget = widgets.Splitter("vertical")
    widget.show()


def test_tabwidget():
    widget = widgets.TabWidget()
    widget.add_tab(widgets.Widget(), "mdi.timer")
    widget.insert_tab(0, widgets.Widget(), "test", "mdi.timer")
    widget.detach_tab(0, core.Point())
    widget.remove_tab(0)
    widget.show()
    widget.close()
    assert True


def test_textbrowser():
    reader = widgets.TextBrowser()
    reader.show()
    reader.close()
    assert True


def test_textedit():
    widget = widgets.TextEdit()
    widget.set_text("test")
    widget.append(" this")
    assert(widget.text() == "test\n this")
    widget.set_font("Consolas")
    widget.set_enabled()
    widget.set_read_only()
    widget.scroll_to_end()
    widget.set_disabled()
    widget.show()


def test_toolbar():
    widget = widgets.Toolbar()
    widget.show()


def test_treeview():
    widget = widgets.TreeView()
    widget.show()


def test_widget():
    widget = widgets.Widget()
    with widget.block_signals():
        pass
    widget.set_enabled()
    widget.set_disabled()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtWidgets
from prettyqt import widgets


class FontDialog(QtWidgets.QFontDialog):
    pass


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    widget = FontDialog.getFont()
    app.exec_()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtWidgets

from prettyqt import widgets


class ColorDialog(QtWidgets.QColorDialog):
    pass


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    widget = ColorDialog()
    widget.show()
    app.exec_()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtWidgets, QtCore

from prettyqt import widgets

TRIGGERS = dict(none=QtWidgets.QAbstractItemView.DoubleClicked,
                double_click=QtWidgets.QAbstractItemView.DoubleClicked,
                edit_key=QtWidgets.QAbstractItemView.EditKeyPressed)

SCROLLBAR_POLICY = dict(always_on=QtCore.Qt.ScrollBarAlwaysOn,
                        always_off=QtCore.Qt.ScrollBarAlwaysOff,
                        as_needed=QtCore.Qt.ScrollBarAsNeeded)

SELECTION_BEHAVIOURS = dict(rows=QtWidgets.QAbstractItemView.SelectRows,
                            columns=QtWidgets.QAbstractItemView.SelectColumns,
                            items=QtWidgets.QAbstractItemView.SelectItems)


class TableView(QtWidgets.QTableView):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)

    def h_header(self):
        return self.horizontalHeader()

    def set_horizontal_scrollbar_visibility(self, mode):
        self.setHorizontalScrollBarPolicy(SCROLLBAR_POLICY[mode])

    def set_selection_behaviour(self, mode):
        self.setSelectionBehaviour(SELECTION_BEHAVIOURS[mode])


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    dlg = widgets.MainWindow()
    status_bar = TableView()
    dlg.show()
    app.exec_()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtGui

from prettyqt import gui


class StandardItemModel(QtGui.QStandardItemModel):

    def __iter__(self):
        items = [self.item(index) for index in range(self.rowCount())]
        return iter(items)

    def add_item(self, label):
        item = gui.StandardItem(label)
        self.appendRow(item)



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

import pathlib

from qtpy import QtGui


class Icon(QtGui.QIcon):

    def __init__(self, icon=None):
        if isinstance(icon, pathlib.Path):
            icon = str(icon)
        super().__init__(icon)


if __name__ == "__main__":
    icon = Icon()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

import qtawesome as qta
from qtpy import QtWidgets


class ToolButton(QtWidgets.QToolButton):

    def set_enabled(self):
        self.setEnabled(True)

    def set_disabled(self):
        self.setEnabled(False)

    def set_icon(self, icon):
        if isinstance(icon, str):
            icon = qta.icon(icon)
        if icon:
            self.setIcon(icon)

    def set_shortcut(self, shortcut):
        if shortcut:
            self.setShortcut(shortcut)

    @classmethod
    def for_menu(cls, menu, icon=None):
        btn = cls()
        btn.setMenu(menu)
        btn.setPopupMode(cls.InstantPopup)
        btn.set_icon(icon)
        return btn



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtWidgets

from prettyqt import widgets


class SpinBox(QtWidgets.QSpinBox):

    def set_enabled(self):
        self.setEnabled(True)

    def set_disabled(self):
        self.setEnabled(False)


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    widget = SpinBox()
    widget.show()
    app.exec_()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `prettyqt` package."""

import pathlib

import pytest

from prettyqt import core


def test_filesystemmodel():
    model = core.FileSystemModel()
    idx = model.index(0, 0)
    data = model.data(idx, model.DATA_ROLE)
    model.yield_child_indexes(idx)


def test_settings():
    settings = core.Settings("1", "2")
    settings.set_value("test", "value")
    assert settings.contains("test")
    assert settings.value("test") == "value"
    with core.Settings("ab") as s:
        s.set_value("test2", "xx")
    with settings.write_array("test"):
        pass
    with settings.read_array("test"):
        pass
    path = pathlib.Path.cwd()
    settings.set_path("native", "user", path)


def test_regexp():
    regex = core.RegExp("[0-9]")
    a = list(regex.matches_in_text("0a4"))
    assert len(a) == 2


def test_threadpool():
    pool = core.ThreadPool()


def test_timer():
    def test():
        pass
    core.Timer.single_shot(test)



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtCore, QtWidgets

from prettyqt import widgets

MODES = dict(maximum=QtWidgets.QLayout.SetMaximumSize,
             fixed=QtWidgets.QLayout.SetFixedSize)

ALIGNMENTS = dict(left=QtCore.Qt.AlignLeft,
                  right=QtCore.Qt.AlignRight,
                  top=QtCore.Qt.AlignTop,
                  bottom=QtCore.Qt.AlignBottom)


class GridLayout(QtWidgets.QGridLayout):

    def __setitem__(self, idx, value):
        row, col = idx
        rowspan = row.stop - row.start + 1 if isinstance(row, slice) else 1
        colspan = col.stop - col.start + 1 if isinstance(col, slice) else 1
        rowstart = row.start if isinstance(row, slice) else row
        colstart = col.start if isinstance(col, slice) else col
        if isinstance(value, QtWidgets.QWidget):
            self.addWidget(value, rowstart, colstart, rowspan, colspan)
        else:
            self.addLayout(value, rowstart, colstart, rowspan, colspan)

    def __getitem__(self, idx):
        if isinstance(idx, tuple):
            return self.itemAtPosition(*idx)
        else:
            return self.itemAt(idx)

    def __iter__(self):
        return iter(self[i] for i in range(self.count()) if self[i] is not None)

    def __len__(self):
        return self.count()

    def set_size_mode(self, mode: str):
        if mode not in MODES:
            raise ValueError(f"{mode} not a valid size mode.")
        self.setSizeConstraint(MODES[mode])

    def set_alignment(self, alignment: str):
        if alignment not in ALIGNMENTS:
            raise ValueError(f"{alignment} not a valid alignment.")
        self.setAlignment(ALIGNMENTS[alignment])


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    layout = GridLayout()
    layout[1, 5:6] = widgets.RadioButton("1")
    layout[3:5, 7:8] = widgets.RadioButton("2")
    layout[3:5, 1:4] = widgets.RadioButton("3")
    widget = widgets.Widget()
    widget.setLayout(layout)
    widget.show()
    app.exec_()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtWidgets

from prettyqt import gui, widgets


class LineEdit(QtWidgets.QLineEdit):

    def set_enabled(self):
        self.setEnabled(True)

    def set_disabled(self):
        self.setEnabled(False)

    def set_font(self,
                 font_name: str,
                 font_size: int = -1,
                 weight: int = -1,
                 italic: bool = False):
        font = gui.Font(font_name, font_size, weight, italic)
        self.setFont(font)

    def append(self, text: str):
        self.set_text(self.text() + text)

    def set_text(self, text: str):
        self.setText(text)

    def set_read_only(self, value: bool):
        """set test to read only

        Args:
            value: True, for read-only, otherwise False
        """
        self.setReadOnly(value)

    def set_regex_validator(self, regex: str) -> gui.RegExpValidator:
        validator = gui.RegExpValidator(self)
        validator.set_regex(regex)
        self.setValidator(validator)
        return validator


if __name__ == "__main__":
    app = widgets.Application.create_default_app()
    widget = LineEdit("This is a test")
    widget.show()
    app.exec_()



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtCore, QtGui

COLORS = dict(transparent=QtCore.Qt.transparent)

PEN_TYPES = dict(none=QtCore.Qt.NoPen)

COMP_MODES = dict(source_at_top=QtGui.QPainter.CompositionMode_SourceAtop)


class Painter(QtGui.QPainter):

    def draw_image(self, point, frame_buffer):
        self.set_composition_mode("source_at_top")
        self.drawImage(point, frame_buffer)
        self.end()

    def use_antialiasing(self):
        self.setRenderHint(self.Antialiasing, True)

    def fill_rect(self, rect, color):
        if color not in COLORS:
            raise ValueError("Invalid value for color.")
        self.fillRect(rect, COLORS[color])

    def set_pen(self, pen_type):
        if pen_type not in PEN_TYPES:
            raise ValueError("Invalid value for pen_type.")
        self.setPen(PEN_TYPES[pen_type])

    def set_color(self, color):
        color = QtGui.QColor(color)
        self.setPen(color)

    def set_composition_mode(self, mode):
        if mode not in COMP_MODES:
            raise ValueError("Invalid value for composition mode.")
        self.setCompositionMode(COMP_MODES[mode])

    def draw_text(self, x, y, width, height, alignment, text):
        # TODO
        alignment = QtCore.Qt.AlignRight
        self.drawText(x, y, width, height, alignment, text)



# -*- coding: utf-8 -*-

"""widgets module

contains QtWidgets-based classes
"""

from .application import Application

from .widget import Widget
from .desktopwidget import DesktopWidget
from .graphicsitem import GraphicsItem
from .style import Style
from .styleoption import StyleOption
from .spaceritem import SpacerItem
from .sizepolicy import SizePolicy
from .stylepainter import StylePainter
from .dialog import Dialog
from .messagebox import MessageBox

from .formlayout import FormLayout
from .boxlayout import BoxLayout
from .gridlayout import GridLayout

from .slider import Slider
from .styleoptionslider import StyleOptionSlider
from .frame import Frame


from .dockwidget import DockWidget

from .mainwindow import MainWindow

from .action import Action
from .widgetaction import WidgetAction
from .toolbutton import ToolButton
from .tooltip import ToolTip
from .menu import Menu
from .menubar import MenuBar
from .statusbar import StatusBar
from .tabbar import TabBar
from .tabwidget import TabWidget
from .toolbar import Toolbar
from .headerview import HeaderView
from .label import Label
from .pushbutton import PushButton
from .radiobutton import RadioButton
from .combobox import ComboBox
from .spinbox import SpinBox
from .doublespinbox import DoubleSpinBox
from .checkbox import CheckBox
from .lineedit import LineEdit
from .textedit import TextEdit
from .dateedit import DateEdit
from .datetimeedit import DateTimeEdit
from .plaintextedit import PlainTextEdit
from .textbrowser import TextBrowser
from .progressbar import ProgressBar
from .listview import ListView
from .treeview import TreeView
from .tableview import TableView

from .splashscreen import SplashScreen
from .progressdialog import ProgressDialog
from .fontdialog import FontDialog
from .filedialog import FileDialog
from .colordialog import ColorDialog
from .dialogbuttonbox import DialogButtonBox
from .buttongroup import ButtonGroup
from .groupbox import GroupBox
from .splitter import Splitter

from .itemdelegate import ItemDelegate

from .composed.spanslider import SpanSlider
from .composed.waitingspinner import WaitingSpinner
from .composed.callout import Callout
from .composed.markdownwidget import MarkdownWindow
from .composed.imageviewer import ImageViewer
from .composed.popupinfo import PopupInfo
from .composed.buttondelegate import ButtonDelegate
from .composed.selectionwidget import SelectionWidget

__all__ = ["Application",
           "Widget",
           "DesktopWidget",
           "GraphicsItem",
           "Style",
           "StyleOption",
           "SpacerItem",
           "SizePolicy",
           "StylePainter",
           "Dialog",
           "MessageBox",
           "FormLayout",
           "BoxLayout",
           "GridLayout",
           "Slider",
           "StyleOptionSlider",
           "Frame",
           "Action",
           "WidgetAction",
           "ToolButton",
           "ToolTip",
           "Menu",
           "MenuBar",
           "StatusBar",
           "TabWidget",
           "TabBar",
           "Toolbar",
           "HeaderView",
           "DockWidget",
           "Label",
           "PushButton",
           "RadioButton",
           "ComboBox",
           "SpinBox",
           "DoubleSpinBox",
           "CheckBox",
           "LineEdit",
           "TextEdit",
           "DateEdit",
           "DateTimeEdit",
           "PlainTextEdit",
           "TextBrowser",
           "ProgressBar",
           "ListView",
           "TreeView",
           "TableView",
           "SplashScreen",
           "ProgressDialog",
           "FontDialog",
           "FileDialog",
           "ColorDialog",
           "DialogButtonBox",
           "ButtonGroup",
           "GroupBox",
           "Splitter",
           "MainWindow",
           "ItemDelegate",
           "SpanSlider",
           "WaitingSpinner",
           "Callout",
           "PopupInfo",
           "ButtonDelegate",
           "SelectionWidget",
           "Image",
           "ImageViewer",
           "MarkdownWindow"]



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtCore


class RegExp(QtCore.QRegExp):

    def matches_in_text(self, text):
        index = self.indexIn(text)
        while index >= 0:
            length = self.matchedLength()
            yield index, length
            index = self.indexIn(text, index + length)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `prettyqt` package."""

import pytest

from prettyqt import gui, core
from qtpy import QtCore


def test_color():
    color = gui.Color()
    color.set_color("gray")


def test_icon():
    icon = gui.Icon()


def test_keysequence():
    assert(gui.KeySequence.to_shortcut_str(0x41, QtCore.Qt.ShiftModifier) == "Shift+A")


def test_standarditemmodel():
    model = gui.StandardItemModel()
    model.add_item("test")


def test_textcharformat():
    fmt = gui.TextCharFormat()
    fmt.set_font_weight("bold")
    fmt.set_foreground_color("yellow")


def test_painter():
    painter = gui.Painter()
    painter.use_antialiasing()
    painter.set_pen("none")
    painter.fill_rect(core.Rect(), "transparent")
    painter.set_color("black")
    painter.set_composition_mode("source_at_top")


def test_pdfwriter():
    writer = gui.PdfWriter("test")
    writer.setup(core.RectF())



# -*- coding: utf-8 -*-
"""
@author: Philipp Temminghoff
"""

from qtpy import QtGui


class Font(QtGui.QFont):

    def set_size(self, size: int):
        pass

    @classmethod
    def mono(cls, size=8):
        font = cls("Consolas", size)
        # font.setStyleHint()
        return font



# -*- coding: utf-8 -*-

"""Top-level package for PrettyQt."""

from . import core, gui, syntaxhighlighters, widgets

__author__ = """Philipp Temminghoff"""
__email__ = "phil65@kodi.tv"
__version__ = "0.17.0"

__all__ = ["core", "widgets", "gui", "syntaxhighlighters"]
